@@ -5,7 +5,7 @@ from functools import lru_cache
 from typing import Any, Iterator, List, Optional
 
 from mkapi.core.base import Base, Object
-from mkapi.core.object import get_object
+from mkapi.core.object import from_object, get_object
 from mkapi.core.tree import Tree
 
 
@@ -95,6 +95,8 @@ def get_kind(obj) -> str:
             return "readonly_property"
     if hasattr(obj, "__dataclass_fields__") and hasattr(obj, "__qualname__"):
         return "dataclass"
+    if hasattr(obj, "__self__") and type(obj.__self__) is type:
+        return "classmethod"
     if inspect.isclass(obj):
         return "class"
     if inspect.isgeneratorfunction(obj):
@@ -108,6 +110,8 @@ def get_kind(obj) -> str:
             arg = list(parameters)[0]
             if arg == "self":
                 return "method"
+        if hasattr(obj, "__qualname__") and "." in obj.__qualname__:
+            return "staticmethod"
         return "function"
     return ""
 
@@ -115,6 +119,8 @@ def get_kind(obj) -> str:
 def is_member(name: str, obj: Any, sourcefile: str) -> bool:
     if isinstance(obj, property):
         return True
+    if name in ["__func__", "__self__"]:
+        return False
     if name.startswith("_"):
         if not name.startswith("__") or not name.endswith("__"):
             return False
@@ -139,7 +145,7 @@ def get_members(obj) -> List[Node]:
         sourcefile = ""
     members = []
     for name, obj in inspect.getmembers(obj):
-        if is_member(name, obj, sourcefile):
+        if is_member(name, obj, sourcefile) and not from_object(obj):
             member = get_node(obj)
             if member.docstring:
                 members.append(member)
