@@ -1,13 +1,20 @@
 from typing import Iterator
 
 
+def strip_ptags(html: str) -> str:
+    html = html.replace("<p>", "").replace("</p>", "<br>")
+    if html.endswith("<br>"):
+        html = html[:-4]
+    return html
+
+
 def convert(text: str) -> str:
     blocks = []
     for block in split(text):
         if block.startswith(">>>"):
             block = f"~~~python\n{block}\n~~~\n"
         blocks.append(block)
-    return "\n".join(blocks).strip() + "\n"
+    return "\n".join(blocks).strip()
 
 
 def delete_indent(lines, start, stop):
